# R/globals.R
utils::globalVariables(c("data", "valor", "Valor", "trimestre", "ultimo_mes",
                         "ano", "taxa",

                         #get_unemployment

                         "month", "year", "rate",

                         #plot_unemployment

                         "ylab"))
